==> vertical_tabs_config-8.x-1.0.tar.gz: vertical_tabs_config/src/Form/OrderConfigurationForm.php <==
<?php

namespace Drupal\vertical_tabs_config\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure order for this site.
 */
class OrderConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vt_order_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'vertical_tabs_config.order',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('vertical_tabs_config.order');

    $order = 0;
    $vertical_tabs = vertical_tabs_config_vertical_tab_list();

    $form['desc'] = array(
      '#type' => 'item',
      '#markup' => t('Set the desired weight for each vertical tab'),
    );

    foreach ($vertical_tabs as $vt_machine_name => $vt_human_name) {
      $form['vertical_tabs_config_' . $vt_machine_name] = array(
        '#type' => 'textfield',
        '#title' => $vt_human_name . ' ' . t('weight'),
        '#default_value' => $config->get('vertical_tabs_config_' . $vt_machine_name),
      );
      $order++;
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $vertical_tabs = vertical_tabs_config_vertical_tab_list();

    foreach ($vertical_tabs as $vt_machine_name => $vt_human_name) {
      $this->config('vertical_tabs_config.order')
        ->set('vertical_tabs_config_' . $vt_machine_name, $values['vertical_tabs_config_' . $vt_machine_name])
        ->save();
    }

    parent::submitForm($form, $form_state);
  }

}

==> vertical_tabs_config-8.x-1.1.tar.gz: vertical_tabs_config/src/Form/OrderConfigurationForm.php <==
<?php

namespace Drupal\vertical_tabs_config\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure order for this site.
 */
class OrderConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vt_order_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'vertical_tabs_config.order',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('vertical_tabs_config.order');

    $order = 0;
    $vertical_tabs = vertical_tabs_config_vertical_tab_list();

    $form['desc'] = array(
      '#type' => 'item',
      '#markup' => $this->t('Set the desired weight for each vertical tab'),
    );

    foreach ($vertical_tabs as $vt_machine_name => $vt_human_name) {
      $form['vertical_tabs_config_' . $vt_machine_name] = array(
        '#type' => 'textfield',
        '#title' => $vt_human_name . ' ' . $this->t('weight'),
        '#default_value' => $config->get('vertical_tabs_config_' . $vt_machine_name),
      );
      $order++;
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $vertical_tabs = vertical_tabs_config_vertical_tab_list();

    foreach ($vertical_tabs as $vt_machine_name => $vt_human_name) {
      $this->config('vertical_tabs_config.order')
        ->set('vertical_tabs_config_' . $vt_machine_name, $values['vertical_tabs_config_' . $vt_machine_name])
        ->save();
    }

    parent::submitForm($form, $form_state);
  }

}
